TeaModel

Trait TeaModel 

pub trait TeaModel:
    'static
    + Default
    + Clone
    + PartialEq {
    type Action;

    // Required method
    fn update(&mut self, action: Self::Action);
}
Trait representing a TEA model in Dioxus.

Required Associated Types

type Action

The type of actions that can be processed by this model.

Required Methods

fn update(&mut self, action: Self::Action)

Updates the model state based on the provided action.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors